@@ -1,4 +1,4 @@
-/* $Id: keyboard-drawing.c,v 1.47 2006/02/28 00:01:08 svu Exp $ */
+/* $Id: keyboard-drawing.c 145 2006-08-27 10:32:18Z rodrigo $ */
 /*
  * keyboard-drawing.c: implementation of a gtk+ widget that is a drawing of
  * the keyboard of the default display
@@ -1073,12 +1073,12 @@ key_event (
     {
       g_signal_emit (drawing, keyboard_drawing_signals[BAD_KEYCODE], 0,
                      event->hardware_keycode);
-      return FALSE;
+      return TRUE;
     }
 
   if ((event->type == GDK_KEY_PRESS && key->pressed) ||
       (event->type == GDK_KEY_RELEASE && !key->pressed))
-    return FALSE;
+    return TRUE;
   /* otherwise this event changes the state we believed we had before */
 
   key->pressed = (event->type == GDK_KEY_PRESS);
@@ -1087,7 +1087,7 @@ key_event (
 
   invalidate_key_region (drawing, key);
 
-  return FALSE;
+  return TRUE;
 }
 
 static gint
